package no.malmanger.seraph;

import java.awt.List;
import java.util.ArrayList;

import org.apache.log4j.Level;
import org.apache.log4j.Logger;

public class RemoteUserConfiguration {

	private static final Logger log = Logger.getLogger(RemoteUserConfiguration.class);
	public final static String PROPERTIES_FILE = "/remoteUserAuthenticator.properties";

	public final static String CREATE_USERS = "create.users";
    public final static String REMOTE_USER_HEADER_NAME_PROPERTY = "header.remote_user";
    public final static String FULLNAME_HEADER_NAME_PROPERTY = "header.fullname";
    public final static String EMAIL_HEADER_NAME_PROPERTY = "header.email";
    public final static String UPDATE_INFO = "update.info";
    public final static String DEFAULT_GROUPS = "user.defaults.groups";
    public final static String UPDATE_GROUPS = "update.groups";
	
    public RemoteUserConfiguration() { // set logger
//    	log.setLevel(Level.DEBUG);
    }
    
    /**
     * Whether to create accounts for new users or not
     */
    private boolean createUsers;
    public void setCreateUsers(boolean createUsers) { this.createUsers = createUsers; }
    public boolean isCreateUsers() { return this.createUsers; }
    
    /**
     * HTTP Header name that contains a user's username
     */
    private String remoteUserHeaderName;
    public void setRemoteUserHeaderName(String remoteUserHeaderName) { log.debug("Setting remoteUserHeaderName = " + remoteUserHeaderName); this.remoteUserHeaderName = remoteUserHeaderName; }
    public String getRemoteUserHeaderName() { log.debug("GET remoteUserHeaderName = " + remoteUserHeaderName); return this.remoteUserHeaderName; }
	
    /**
     * HTTP Header name that contains a user's full name
     */
    private String fullNameHeaderName;
    public void setFullNameHeaderName(String fullNameHeaderName) { this.fullNameHeaderName = fullNameHeaderName; }
    public String getFullNameHeaderName() { return this.fullNameHeaderName; }

    /**
     * HTTP Header name that contains a user's email address
     */
    private String emailHeaderName;
    public void setEmailHeaderName(String emailHeaderName) { this.emailHeaderName = emailHeaderName; }
    public String getEmailHeaderName() { return this.emailHeaderName; }
    
    /**
     * Whether or not to update name/email info for previously created users
     */
    private boolean updateInfo;
    public void setUpdateInfo(boolean updateInfo) { this.updateInfo = updateInfo; }
    public boolean isUpdateInfo() { return this.updateInfo; }
   
    /**
     * Whether or not to update default groups for previously created users
     */
    private boolean updateGroups;
    public void setUpdateGroups(boolean updateGroups) { this.updateGroups = updateGroups; }
    public boolean isUpdateGroups() { return this.updateGroups; }
   
    /**
     * Default groups new users should be member of (comma separated string)
     */
    private ArrayList<String> defaultGroups;
    public void setDefaultGroups(String groups) {
    	log.debug("Set groups...");
    	this.defaultGroups = new ArrayList<String>();
    	String[] list = groups.split(",");

    	for (String element: list) {
    		log.debug("    group:" + element.trim());
    		defaultGroups.add(element.trim());
    	}
    }
    public ArrayList<String> getDefaultGroups() { 
    	return this.defaultGroups; 
    }
}
